Class SPGame extends xDeathmatch config;

var bool bEndGame;
var bool bTransition;
var(LoadingHints) private localized array<string> JiggaHints;

Struct Saved_PRI
{
        Var Int LightSuitPower;
        Var Int BlinderPower;
        Var Int StealthPower;
	Var Int Credits;
};

Struct Saved_Weapon
{
        Var String WeaponClass;
        Var Int Primary_Ammo;
        Var Int Secondary_Ammo;
};

Struct Variable_Info
{
        Var String Variable_Name;
        Var String Variable_Value;
};

Struct Saved_Inventory
{
        Var String Inventory_Class;
        Var int NumCopies;
};

Struct Saved_Player_Details
{
        Var Array<Saved_Weapon> Player_Weapons;
        Var Array<Saved_Inventory> Player_Inventory;
        // Var Saved_PRI Player_PRI;
        
        Var String Player_Hash;       
};

Var Config Array<Saved_Player_Details> Player_Info;

Function ResetPlayerInfo()
{
        Player_Info.Length = 0;
	SaveConfig();
}

function PostBeginPlay()
{
	Super.PostBeginPlay();
}

function Bot SpawnBot(optional string botName)
{
    	local Bot B;

    	return B;
}

static function array<string> GetAllLoadHints(optional bool bThisClassOnly)
{
	local int i;
	local array<string> Hints;

	if (default.JiggaHints.Length == 0 )
		Hints = Super.GetAllLoadHints();

	for (i = 0; i < default.JiggaHints.Length; i++)
		Hints[Hints.Length] = default.JiggaHints[i];

	return Hints;
}

function bool AddBot(optional string botName)
{
	return false;
}

function NavigationPoint FindPlayerStart( Controller Player, optional byte InTeam, optional string incomingName )
{
    local NavigationPoint N, BestStart;
    local Teleporter Tel;
    local float BestRating, NewRating;
    local byte Team;

    // always pick StartSpot at start of match
    if ( (Player != None) && (Player.StartSpot != None) && (Level.NetMode == NM_Standalone)
        && (bWaitingToStartMatch || ((Player.PlayerReplicationInfo != None) && Player.PlayerReplicationInfo.bWaitingPlayer))  )
    {
        return Player.StartSpot;
    }

    if ( GameRulesModifiers != None )
    {
        N = GameRulesModifiers.FindPlayerStart(Player,InTeam,incomingName);
        if ( N != None )
            return N;
    }

    // if incoming start is specified, then just use it
    if( incomingName!="" )
        foreach AllActors( class 'Teleporter', Tel )
            if( string(Tel.Tag)~=incomingName )
                return Tel;

    // use InTeam if player doesn't have a team yet
    if ( (Player != None) && (Player.PlayerReplicationInfo != None) )
    {
        if ( Player.PlayerReplicationInfo.Team != None )
            Team = Player.PlayerReplicationInfo.Team.TeamIndex;
        else
            Team = InTeam;
    }
    else
        Team = InTeam;

    for ( N=Level.NavigationPointList; N!=None; N=N.NextNavigationPoint )
    {
        NewRating = RatePlayerStart(N,Team,Player);
        if ( NewRating > BestRating )
        {
            BestRating = NewRating;
            BestStart = N;
        }
    }

    if ( SPPlayerStart(BestStart) == None )
    {
        log("Warning - PATHS NOT DEFINED or NO PLAYERSTART with positive rating");
		BestRating = -100000000;
        ForEach AllActors( class 'NavigationPoint', N )
        {
            NewRating = RatePlayerStart(N,0,Player);
            if ( InventorySpot(N) != None )
				NewRating -= 50;
			NewRating += 20 * FRand();
            if ( NewRating > BestRating )
            {
                BestRating = NewRating;
                BestStart = N;
            }
        }
    }

    return BestStart;
}

function float RatePlayerStart(NavigationPoint N, byte Team, Controller Player)
{
    local PlayerStart P;
    local float Score;
    //local Controller OtherPlayer;

    P = SPPlayerStart(N);

    if ( (P == None) || !P.bEnabled || P.PhysicsVolume.bWaterVolume )
        return -99999999999999;

    else if ( P.bEnabled )
		Score = 99999999999999999999999999;

    return FMax(Score, 5);
}

event InitGame(string Options, out string Error)
{
	Super.InitGame(Options, Error);
	SetGameSpeed(0.9);
}

simulated function Timer()
{
	super.Timer();

	if (bEndGame)
	{
		EndGame(None, "TimeLimit");
	}
}

auto State PendingMatch
{
	function RestartPlayer(Controller aPlayer)
	{
		if ( CountDown <= 0 )
			Super.RestartPlayer(aPlayer);
	}

    function bool AddBot(optional string botName)
    {
        if ( Level.NetMode == NM_Standalone )
            InitialBots++;
        if ( botName != "" )
			PreLoadNamedBot(botName);
		else
			PreLoadBot();
        return true;
    }

    	function Timer()
    	{
		Global.Timer();
	}

    function beginstate()
    {
		bWaitingToStartMatch = false;
        StartupStage = 0;
	//StartMatch();
    }

Begin:
	StartMatch();
}

function int ReduceDamage(int Damage, pawn injured, pawn instigatedBy, vector HitLocation, out vector Momentum, class<DamageType> DamageType)
{
	if (Monster(Injured) != None)
	{
		if (Monster(Injured).SameSpeciesAs(InstigatedBy))
			return 0;
		//return Damage;
	}

	if (instigatedBy.IsA('Pawn') && !instigatedBy.IsA('Monster') && injured.IsA('Pawn') && !injured.IsA('Monster'))
	{
		return 0;
		//return damage;
	}

	else
		return Super.ReduceDamage(Damage,injured,instigatedBy,HitLocation,Momentum,DamageType);
}

function AddGameSpecificInventory(Pawn P)
{
	local SPLevelInfo I;

	bAllowTrans = false;

	if (!P.IsA('SPMonster'))
	{
		foreach AllActors(class'SPLevelInfo', I)
		{
			if (I != None)
			{
				I.LoadMeUp(P);
			}
		}

	}
}

Function DumpPlayerInfo(PlayerController C)
{
        Local Int i, k, a;
        Local Inventory Inv;

	i = -1;
        
	For (i = 0; i < Player_Info.Length; i++)
	{
		If (Player_Info[i].Player_Hash == C.GetPlayerIDHash())
		{
			Player_Info.Remove(i, 1);
		}
	}

	If (i == -1)
	{
		i = Player_Info.Length;
	}
        else
        {
		i = Player_Info.Length;
        }

	Player_Info.Insert(i, 1);

	Player_Info[i].Player_Hash = C.GetPlayerIDHash();
        
        For (Inv = C.Pawn.Inventory; Inv != None; Inv = Inv.Inventory )
                {
                If (Weapon(Inv) != None) // Fill in the blanks.
                        {
                        k = Player_Info[i].Player_Weapons.Length;
			Player_Info[i].Player_Weapons.Insert(k, 1);
                        Player_Info[i].Player_Weapons[k].WeaponClass = String(Inv.Class);
                        Player_Info[i].Player_Weapons[k].Primary_Ammo = Weapon(Inv).AmmoCharge[0];
                        Player_Info[i].Player_Weapons[k].Secondary_Ammo = Weapon(Inv).AmmoCharge[1];
                        }

                If (Powerups(Inv) != None) // Fill in the blanks.
                        {
                        a = Player_Info[i].Player_Inventory.Length;
			Player_Info[i].Player_Inventory.Insert(a, 1);
                        Player_Info[i].Player_Inventory[a].Inventory_Class = String(Inv.Class);
                        Player_Info[i].Player_Inventory[a].NumCopies = Powerups(Inv).NumCopies;
                        }
                }
        // as many of these as you need. Also modify the struct
        
        SaveConfig();
}

Function LoadPlayerInfo(PlayerController C)
{
        Local Int i, k, a;
        Local Weapon W;
        Local Inventory Inv;
	Local int NumGiveTo;

	Player_Info.Insert(i, 1);

        For (i = 0; i < Player_Info.Length; i++)
                {
                If (Player_Info[i].Player_hash == C.GetPlayerIDHash())
                        {
                        Break;
                        }
                }

	Player_Info[i].Player_Weapons.Insert(k, 1);
        
        For (k = 0; k < Player_Info[i].Player_Weapons.Length; k++) // fix - setprimaryammoto to the right variable name
        {
                W = Spawn(Class<Weapon>(DynamicLoadObject(Player_Info[i].Player_Weapons[k].WeaponClass, Class'Class')));
		if (W != None && C.Pawn != None)
		{
                	W.GiveTo(C.Pawn);
                
                	W.AmmoCharge[0] = Player_Info[i].Player_Weapons[k].Primary_Ammo;
                	W.AmmoCharge[1] = Player_Info[i].Player_Weapons[k].Secondary_Ammo;
		}

        }
        
        For (a = 0; a < Player_Info[i].Player_Inventory.Length; a++)
                {
                Inv = Spawn(Class<Inventory>(DynamicLoadObject(Player_Info[i].Player_Inventory[a].Inventory_Class, Class'Class')));
		NumGiveTo = Player_Info[i].Player_Inventory[a].NumCopies;
			if (Inv != None && C.Pawn != None)
			{
	                	Inv.GiveTo(C.Pawn);
				Powerups(Inv).NumCopies = NumGiveTo;
			}
                }
}

function RestartPlayer(Controller aPlayer)
{
	local SPLevelInfo O;
	local SPPlayer P;
	local bool bRespawning;

	P = SPPlayer(aPlayer);

	Super.RestartPlayer(aPlayer);

	foreach AllActors(class'SPLevelInfo', O)
	{
		if (O != None)
		{
			bTransition = O.bIsATransition;
		}
	}

	if (P != None)
	{
		bRespawning = P.bRespawning;
	}

	log("RESPAWN HURR:" @ bRespawning);

	if (bTransition || bRespawning)
	{
		if (PlayerController(aPlayer) != None)
			LoadPlayerInfo(PlayerController(aPlayer));
	}
}

defaultproperties
{
     	LoginMenuClass="GUI2K4.UT2K4PlayerLoginMenu"
	DefaultPlayerClassName="CodeBase.SPPawn"
	Description="Single Player Framework to use either as a template for a full SP mod or for a series of maps."
	GameName="Single Player"
        MapListType="CodeBase.SPMapList"
        MutatorClass="CodeBase.SPMutator"
     	ScreenShotName="SPTextures.GUI.spframemenu"
	TimeLimit=0
	GoalScore=0
	bAllowTrans=false
	Acronym="SP"
	MapPrefix="SP"
	//EndGameSound[0]=None
	//EndGameSound[1]=None
	//AltEndGameSound[0]=None
	//AltEndGameSound[1]=None
     	PlayerControllerClassName="CodeBase.SPPlayer"
     	HUDType="CodeBase.SPHUD"
	bAllowVehicles=true
	bQuickStart=true
	JiggaHints(0)="Don't forget to collect credits - you never know when they might come in useful."
	JiggaHints(1)="If the player receives a Hidden message, he or she is exactly that."
	JiggaHints(2)="Trouble seeing down a dark corridor? Use a Flare or Blinder."
	JiggaHints(3)="Don't forget to bind your Inventory keys in the Controls menu."
	JiggaHints(4)="If you hit a checkpoint, when you die you will respawn at that spot."
	JiggaHints(5)="Use gambling machines with care - there is a 50/50 chance of you either losing credits or losing them."
	JiggaHints(6)="Collectable health packs can be used to replenish health on the move."
	JiggaHints(7)="Conventional reason does not work with the Queen. If you are in her sights, you are already dead."
	JiggaHints(8)="Be careful to avoid the inevitable traps when collecting enticing items."
	JiggaHints(9)="Read any messages that appear on screen - you never know when they may contain useful information."
	JiggaHints(10)="Stuck in a corridor where they only way is up? Try dodging..."
	JiggaHints(11)="The Night Vision powerup can help you avoid potentially nasty traps."
	JiggaHints(12)="Be sure to save your juicier weapons for the faster and tougher enemies."
	JiggaHints(13)="The art of liftjumping is not just restricted to multiplayer games."
	JiggaHints(14)="Hacking devices can leave you open and vulnerable to attack."
}