Class SPHud extends HudCDeathmatch;

var(Gfx) float testX;
var(Gfx) float testY;

var(Gfx) float borderX;
var(Gfx) float borderY;

var(Gfx) float focusX;
var(Gfx) float focusY;
var(Gfx) float innerArrowsX;
var(Gfx) float innerArrowsY;
var(Gfx) color ArrowColor;
var(Gfx) Color TargetColor;
var(Gfx) Color NoTargetColor;
var(Gfx) Color FocusColor;
var(Gfx) Color ChargeColor;

var(Gfx) vector RechargeOrigin;
var(Gfx) vector RechargeSize;

var transient float LastFOV;
var() bool zoomed;
var() xEmitter  chargeEmitter; // Thanks SniperRifle

var float RadarPulse,RadarScale;
var config float RadarPosX, RadarPosY;
var float LastDrawRadar;
var float MinEnemyDist;
var bool bNVOn;

simulated function PostRender(Canvas C)
{
	local SPPawn P;

	P = SPPawn(PawnOwner);

	DrawInventory(C);

	if (P != None)
	{
		bNVOn = P.bNV;
	}

	RenderOverlays(C);
	if (bNVOn)
		PlayerOwner.RendMap = 6; // Unlit - can't see anything otherwise. :x
	else
		PlayerOwner.RendMap = 5;

    	Super.PostRender(C);
}

simulated function UpdatePrecacheMaterials()
{
	Level.AddPrecacheMaterial(Material'InterfaceContent.HUD.SkinA');
	Super.UpdatePrecacheMaterials();
}

simulated function RenderOverlays(Canvas Canvas)
{
	local float tileScaleX;
	local float tileScaleY;
	local float bX;
	local float bY;
	local float fX;
	local float fY;

	local float tX;
	local float tY;

	local float barOrgX;
	local float barOrgY;
	local float barSizeX;
	local float barSizeY;

	tileScaleX = Canvas.SizeX / 640.0f;
	tileScaleY = Canvas.SizeY / 480.0f;

	bX = borderX * tileScaleX;
	bY = borderY * tileScaleY;
	fX = focusX * tileScaleX;
	fY = focusY * tileScaleX;

	tX = testX * tileScaleX;
	tY = testY * tileScaleX;

	barOrgX = RechargeOrigin.X * tileScaleX;
	barOrgY = RechargeOrigin.Y * tileScaleY;

	barSizeX = RechargeSize.X * tileScaleX;
	barSizeY = RechargeSize.Y * tileScaleY;

	if (bNVOn)
	{
		Canvas.DrawColor.R = 0;
		Canvas.DrawColor.G = 128;
		Canvas.DrawColor.B = 0;
		Canvas.DrawColor.A = 255;
	
	  	Canvas.Style = 255;
		Canvas.SetPos(0,0);
	  	Canvas.DrawTile(Material'ZoomFB', Canvas.SizeX, Canvas.SizeY, 0.0, 0.0, 512, 512 );
	
		Canvas.SetPos(0,0);
		Canvas.DrawTile(Texture'SniperBorder', bX, bY, 0.0, 0.0, Texture'SniperBorder'.USize, Texture'SniperBorder'.VSize);
	
		Canvas.SetPos(Canvas.SizeX-bX,0);
		Canvas.DrawTile(Texture'SniperBorder', bX, bY, 0.0, 0.0, -Texture'SniperBorder'.USize, Texture'SniperBorder'.VSize);
	
		Canvas.SetPos(Canvas.SizeX-bX,Canvas.SizeY-bY);
		Canvas.DrawTile(Texture'SniperBorder', bX, bY, 0.0, 0.0, -Texture'SniperBorder'.USize, -Texture'SniperBorder'.VSize);
	
		Canvas.SetPos(0,Canvas.SizeY-bY);
		Canvas.DrawTile(Texture'SniperBorder', bX, bY, 0.0, 0.0, Texture'SniperBorder'.USize, -Texture'SniperBorder'.VSize);
	
		Canvas.DrawColor = FocusColor;
	
		Canvas.SetPos((Canvas.SizeX*0.5)-fX,(Canvas.SizeY*0.5)-fY);
		Canvas.DrawTile(Texture'SniperFocus', fX*2.0, fY*2.0, 0.0, 0.0, Texture'SniperFocus'.USize, Texture'SniperFocus'.VSize);
	
	  	fX = innerArrowsX * tileScaleX;
		fY = innerArrowsY * tileScaleY;
	
	  	Canvas.DrawColor = ArrowColor;
	  	Canvas.SetPos((Canvas.SizeX*0.5)-fX,(Canvas.SizeY*0.5)-fY);
		Canvas.DrawTile(Texture'SniperArrows', fX*2.0, fY*2.0, 0.0, 0.0, Texture'SniperArrows'.USize, Texture'SniperArrows'.VSize);

		Canvas.DrawColor.R = 0;
		Canvas.DrawColor.G = 128;
		Canvas.DrawColor.B = 0;
		Canvas.DrawColor.A = 255;
	}
}

simulated function DrawInventory(Canvas C)
{
	local float XL, YL;
	local string Name;
	local int Number;
	local SPInventoryItem Item;

	C.Font = GetFontSizeIndex(C,0);
	C.DrawColor = C.MakeColor(255,30,30);

	if (SPPawn(PawnOwner) != None && SPPawn(PawnOwner).bInventoryOn)
	{
		Item = SPInventoryItem(SPPawn(PawnOwner).SelectedItem);

		if (Item != None)
		{
			if (Item.bCanHaveMultipleCopies)
			{
				Number = Item.NumCopies + 1; // NumCopies begins at 0..
				Name = Item.PowerupName;
	
				C.StrLen(Name $ ":" @ Number,XL,YL);
				C.SetPos(C.ClipX - XL,0);
				C.DrawText(Name $ ":" @ Number);
			}

			else
			{
				Name = Item.PowerupName;
	
				C.StrLen(Name,XL,YL);
				C.SetPos(C.ClipX - XL,0);
				C.DrawText(Name);
			}
		}

		else
		{
			C.StrLen("No Inventory Items",XL,YL);
			C.SetPos(C.ClipX - XL,0);
			C.DrawText("No Inventory Items");
		}
	}
}