Class SPMonster_FireTitan extends SPMonster;

simulated function SpawnGiblet( class<Gib> GibClass, Vector Location, Rotator Rotation, float GibPerterbation )
{
    local Gib Giblet;
    local Vector Direction, Dummy;

    if( (GibClass == None) || class'GameInfo'.static.UseLowGore() )
        return;
	
	Instigator = self;
    Giblet = Spawn( GibClass,,, Location, Rotation );

    if( Giblet == None )
        return;

	//Giblet.SetDrawScale(Giblet.DrawScale * (CollisionRadius*CollisionHeight)/1100); // 1100 = 25 * 44
    GibPerterbation *= 32768.0;
    Rotation.Pitch += ( FRand() * 2.0 * GibPerterbation ) - GibPerterbation;
    Rotation.Yaw += ( FRand() * 2.0 * GibPerterbation ) - GibPerterbation;
    Rotation.Roll += ( FRand() * 2.0 * GibPerterbation ) - GibPerterbation;

    GetAxes( Rotation, Dummy, Dummy, Direction );

    Giblet.Velocity = Velocity + Normal(Direction) * 512.0;
}

simulated function PlayDying(class<DamageType> DamageType, vector HitLoc)
{
	AmbientSound = None;
    bCanTeleport = false; 
    bReplicateMovement = false;
    bTearOff = true;
    bPlayedDeath = true;
		
	HitDamageType = DamageType; // these are replicated to other clients
    TakeHitLocation = HitLoc;
	LifeSpan = RagdollLifeSpan;

    GotoState('Dying');
		
	Velocity += TearOffMomentum;
    BaseEyeHeight = Default.BaseEyeHeight;
    SetPhysics(PHYS_Falling);

	PlayAnim('TDeat001',1.2,0.05);
}

function SpawnRock()
{
	FireProjectile();
}

function SlapDamageTarget()
{
	if (MeleeDamageTarget(50, 21000 * Normal(Controller.Target.Location - Location)))
		PlaySound(sound'CodeBaseMonsters.Sounds.titanpunch',SLOT_Interact);
}

function Stomp()
{
	local Pawn P;

	foreach VisibleCollidingActors(class'Pawn', P, 800)
		if (P != Self && !P.IsA('Monster'))
		{
			P.SetPhysics(PHYS_Falling);
			P.AddVelocity(Vect(0,0,490));
		}
}

function RangedAttack(Actor A)
{
	if (bShotAnim)
		return;

	else if ( VSize(A.Location - Location) < MeleeRange + CollisionRadius + A.CollisionRadius )
	{
		if (frand() > 0.5)
		{
			PlaySound(sound'CodeBaseMonsters.Sounds.titanpunch',SLOT_Talk);
			SetAnimAction('TSlap001');
		}

		else
		{
			PlaySound(sound'CodeBaseMonsters.Sounds.titancry',SLOT_Talk);
			SetAnimAction('TStom001');
		}
	}	
	else
	{
		SetAnimAction('TThro001');
	}
	Controller.bPreparingMove = true;
	Acceleration = vect(0,0,0);
	bShotAnim = true;
}

defaultproperties
{
	MeleeRange=120
     ScoringValue=60
     CollisionRadius=115.000000
     CollisionHeight=110.000000
     Mass=2000.000000
     Mesh=VertMesh'CodeBaseMonsters.Titan1'
     Skins(0)=Texture'SPMonsterTex.monsters.firetitan'
     Skins(1)=Texture'SPMonsterTex.monsters.firetitan'
	Health=3000
     bCanDodge=False
     bCanCrouch=False
     AmmunitionClass=Class'SPMonster_FireTitan_Ammo'
	bCanPickupInventory=False
		GroundSpeed = 250
		WaterSpeed = 150
		AirSpeed = 100
		bCanDoubleJump = False
		bCanWallDodge = False
		bCanDodgeDoubleJump = False
		JumpZ = 0
		LandAnims(0) = "TWalk001"
		LandAnims(1) = "TWalk001"
		LandAnims(2) = "TWalk001"
		LandAnims(3) = "TWalk001"
		AirAnims(0) = "TWalk001"
		AirAnims(1) = "TWalk001"
		AirAnims(2) = "TWalk001"
		AirAnims(3) = "TWalk001"
		MovementAnims(0) = "TWalk001"
		MovementAnims(1) = "TWalk001"
		MovementAnims(2) = "TWalk001"
		MovementAnims(3) = "TWalk001"
		WalkAnims(0) = "TWalk001"
		WalkAnims(1) = "TWalk001"
		WalkAnims(2) = "TWalk001"
		WalkAnims(3) = "TWalk001"
		IdleSwimAnim = "TWalk001"
		IdleWeaponAnim = "TSnif001"
		IdleRestAnim = "TSnif001"
		AirStillAnim = "TSnif001"
		TakeOffStillAnim = "TSnif001"
		SwimAnims(0) = "TWalk001"
		SwimAnims(1) = "TWalk001"
		SwimAnims(2) = "TWalk001"
		SwimAnims(3) = "TWalk001"
		CrouchAnims(0) = "TWalk001"
		CrouchAnims(1) = "TWalk001"
		CrouchAnims(2) = "TWalk001"
		CrouchAnims(3) = "TWalk001"
		TakeOffAnims(0) = "TWalk001"
		TakeOffAnims(1) = "TWalk001"
		TakeOffAnims(2) = "TWalk001"
		TakeOffAnims(3) = "TWalk001"
		DodgeAnims(0) = "TStom001"
		DodgeAnims(1) = "TStom001"
		DodgeAnims(2) = "TStom001"
		DodgeAnims(3) = "TStom001"
		TurnLeftAnim = "TStom001"
		TurnRightAnim = "TStom001"
     		IdleChatAnim="TFist"

	DetectionRadius=256
	HearingThreshold=256
	SightRadius=9000
	bForgetful=false
}