Class SPMonster_Trooper extends SPMonster;

var sound FootStep[2];
var name DeathAnim[4];

function PlayVictory()
{
	Controller.bPreparingMove = true;
	Acceleration = vect(0,0,0);
	bShotAnim = true;
    PlaySound(sound'hairflp2sk',SLOT_Interact);	
	Controller.Destination = Location;
	Controller.GotoState('TacticalMove','WaitForAnim');
}

simulated function AnimEnd(int Channel)
{
	local name Anim;
	local float frame,rate;
	
	if ( Channel == 0 )
	{
		GetAnimParams(0, Anim,frame,rate);
		if ( Anim == 'looking' )
			IdleWeaponAnim = 'guncheck';
		else if ( (Anim == 'guncheck') && (FRand() < 0.5) )
			IdleWeaponAnim = 'looking';
	}
	Super.AnimEnd(Channel);
}

function RunStep()
{
	PlaySound(FootStep[Rand(2)], SLOT_Interact);
}

function WalkStep()
{
	PlaySound(FootStep[Rand(2)], SLOT_Interact,0.2);
}

simulated function PlayDying(class<DamageType> DamageType, vector HitLoc)
{
	AmbientSound = None;
    bCanTeleport = false; 
    bReplicateMovement = false;
    bTearOff = true;
    bPlayedDeath = true;
		
	HitDamageType = DamageType; // these are replicated to other clients
    TakeHitLocation = HitLoc;
	LifeSpan = RagdollLifeSpan;

    GotoState('Dying');
		
	Velocity += TearOffMomentum;
    BaseEyeHeight = Default.BaseEyeHeight;
    SetPhysics(PHYS_Falling);
    
    if ( (DamageType == class'DamTypeSniperHeadShot')
		|| ((HitLoc.Z > Location.Z + 0.75 * CollisionHeight) && (FRand() > 0.5) 
			&& (DamageType != class'DamTypeAssaultBullet') && (DamageType != class'DamTypeMinigunBullet') && (DamageType != class'DamTypeFlakChunk')) )
    {
		PlayAnim('Death5',1,0.05);
		CreateGib('head',DamageType,Rotation);
		return;
	}
	if ( Velocity.Z > 300 )
	{
		if ( FRand() < 0.5 )
			PlayAnim('Death',1.2,0.05);
		else
			PlayAnim('Death2',1.2,0.05);
		return;
	}
	PlayAnim(DeathAnim[Rand(4)],1.2,0.05);		
}

function FireShot()
{
	FireProjectile();
}

function ClawDamageTarget()
{
	if ( MeleeDamageTarget(25, (25000 * Normal(Controller.Target.Location - Location))) )
		PlaySound(sound'clawhit1s', SLOT_Interact);			
}

function RangedAttack(Actor A)
{
	
	if (bShotAnim)
		return;
	bShotAnim = true;
	if ( VSize(A.Location - Location) < MeleeRange + CollisionRadius + A.CollisionRadius )
	{
		SetAnimAction('Claw');	
		PlaySound(sound'Claw2s', SLOT_Interact);
		Controller.bPreparingMove = true;
		Acceleration = vect(0,0,0);
	}	
	else if ( Velocity == vect(0,0,0) )
	{
		PlaySound(Sound'WeaponSounds.BaseImpactAndExplosions.BLightningGunExplosion',SLOT_Talk);
		SetAnimAction('Firing');
		Controller.bPreparingMove = true;
		Acceleration = vect(0,0,0);
	}
	else
	{
		PlaySound(Sound'WeaponSounds.BaseImpactAndExplosions.BLightningGunExplosion',SLOT_Talk);
		SetAnimAction('JogFire');
		Controller.bPreparingMove = true;
	}
}

defaultproperties
{
     Footstep(0)=SkaarjPack_rc.Cow.walkC
     Footstep(1)=SkaarjPack_rc.Cow.walkC
     DeathAnim(0)="Death"
     DeathAnim(1)="Death2"
     DeathAnim(2)="Death3"
     DeathAnim(3)="Death4"
     HitSound(0)=SkaarjPack_rc.Skaarj.injur1sk
     HitSound(1)=SkaarjPack_rc.Skaarj.injur2sk
     HitSound(2)=SkaarjPack_rc.Skaarj.injur3sk
     HitSound(3)=SkaarjPack_rc.Skaarj.injur3sk
     DeathSound(0)=SkaarjPack_rc.Skaarj.death1sk
     DeathSound(1)=SkaarjPack_rc.Skaarj.death2sk
     ChallengeSound(0)=SkaarjPack_rc.Skaarj.chalnge1s
     ChallengeSound(1)=SkaarjPack_rc.Skaarj.chalnge3s
     ChallengeSound(2)=SkaarjPack_rc.Skaarj.roam11s
     ChallengeSound(3)=SkaarjPack_rc.Skaarj.roam11s
     AmmunitionClass=CodeBase.TrooperAmmo
     ScoringValue=6
     MeleeRange=60.000000
     JumpZ=550.000000
     Health=150
     		IdleChatAnim="guncheck"
		LandAnims(0) = "Landed"
		LandAnims(1) = "Landed"
		LandAnims(2) = "Landed"
		LandAnims(3) = "Landed"
		AirAnims(0) = "InAir"
		AirAnims(1) = "InAir"
		AirAnims(2) = "InAir"
		AirAnims(3) = "InAir"
		WalkAnims(0) = "Walk"
		WalkAnims(1) = "Walk"
		WalkAnims(2) = "Walk"
		WalkAnims(3) = "Walk"
		IdleSwimAnim = "Swim"
		IdleWeaponAnim = "Fighter"
		IdleRestAnim = "Fighter"
		IdleHeavyAnim = "Fighter"
		IdleRifleAnim = "Fighter"
		AirStillAnim = "Jump2"
		TakeOffStillAnim = "Jump2"
		TakeOffAnims(0) = "Jump2"
		TakeOffAnims(1) = "Jump2"
		TakeOffAnims(2) = "Jump2"
		TakeOffAnims(3) = "Jump2"
		SwimAnims(0) = "Swim"
		SwimAnims(1) = "Swim"
		SwimAnims(2) = "Swim"
		SwimAnims(3) = "Swim"
     		IdleCrouchAnim="guncheck"
		DoubleJumpAnims(0) = "FullJump"
		DoubleJumpAnims(1) = "FullJump"
		DoubleJumpAnims(2) = "FullJump"
		DoubleJumpAnims(3) = "FullJump"
		DodgeAnims(0) = "Lunge"
		DodgeAnims(1) = "Lunge"
		DodgeAnims(2) = "RightDodge"
		DodgeAnims(3) = "LeftDodge"
		MovementAnims(0) = "Jog"
		MovementAnims(1) = "Jog"
		MovementAnims(2) = "Jog"
		MovementAnims(3) = "Jog"
		TurnLeftAnim = "Fighter"
		TurnRightAnim = "Fighter"

     		CrouchAnims(0)="DuckWalk"
     		CrouchAnims(1)="DuckWalk"
     		CrouchAnims(2)="DuckWalk"
     		CrouchAnims(3)="DuckWalk"
     		CrouchTurnRightAnim="DuckWalk"
     		CrouchTurnLeftAnim="DuckWalk"
     		WallDodgeAnims(0)="Lunge"
     		WallDodgeAnims(1)="Lunge"
     		WallDodgeAnims(2)="RightDodge"
     		WallDodgeAnims(3)="LeftDodge"
     Mesh=VertMesh'CodeBaseMonsters.sktrooper'
     Skins(0)=Texture'CodeBaseMonsters.Skins.sktrooper1'
     Mass=150.000000
     Buoyancy=150.000000
     RotationRate=(Yaw=60000)

	DetectionRadius=64
	HearingThreshold=4096
	SightRadius=6000
	bForgetful=false
}