Class SPPawn extends xPawn;

var bool On;
var int InvItem;
var A_BlinderLight A;
var bool bInventoryOn;
var bool bLightSystem;
var bool bRespawning;
var bool bNV;
var bool bAdjustDodgeZ;
var int DodgeZAmount;

replication
{	
	reliable if (Role == ROLE_Authority)
		bNV, bInventoryOn, ClientSetMusic, On, bRespawning, bLightSystem;
}

function PostBeginPlay()
{
	local SPLevelInfo O;

	Super.PostBeginPlay();

	foreach AllActors(class'SPLevelInfo', O)
	{
		bInventoryOn = O.bUseInventory;
		bLightSystem = O.bUseLightingSystem;
		bAdjustDodgeZ = O.bIncreaseDodgeHeight;
		DodgeZAmount = O.DodgeHeight;
	}

	SetTimer(0.2, true);
}

function bool AddInventory(inventory NewItem)
{
	// Skip if already in the inventory.
	local inventory Inv;
	local actor Last, Prev;
	local bool bAddedInOrder;

	Last = self;

	// The item should not have been destroyed if we get here.
	if (NewItem ==None )
		log("tried to add none inventory to "$self);

	NewItem.SetOwner(Self);
	NewItem.NetUpdateTime = Level.TimeSeconds - 1;

	if (NewItem.IsA('Powerups'))
	{
		for (Inv=Inventory; Inv != None; Inv=Inv.Inventory)
		{
			if (Inv == NewItem)
				Powerups(Inv).NumCopies += 1;
		}
	}

	// order weapons based on priority
	if ( Weapon(NewItem) != None )
	{
		Prev = self;
		for( Inv=Inventory; Inv!=None; Inv=Inv.Inventory )
		{
			if ( (Inv.InventoryGroup == NewItem.InventoryGroup) && (Weapon(Inv) != None) )
			{
				if( (Weapon(Inv).Priority < Weapon(NewItem).Priority) )
				{
					bAddedInOrder = true;
					break;
				}
			}
			else if ( (Weapon(Prev) != None) && (Weapon(Prev).InventoryGroup == NewItem.InventoryGroup) )
			{
				bAddedInOrder = true;
				break;
			}
			if ( !bAddedInOrder )
				Prev = Inv;
		}
		if ( bAddedInOrder )
		{
			NewItem.Inventory = Prev.Inventory;
			Prev.Inventory = NewItem;
			Prev.NetUpdateTime = Level.TimeSeconds - 1;
		}
	}

	if ( !bAddedInOrder )
	{
		for( Inv=Inventory; Inv!=None; Inv=Inv.Inventory )
		{
			if( Inv == NewItem )
				return false;
			Last = Inv;
		}

		// Add to back of inventory chain (so minimizes net replication effect).
		NewItem.Inventory = None;
		Last.Inventory = NewItem;
		Last.NetUpdateTime = Level.TimeSeconds - 1;
	}
	if ( Controller != None )
		Controller.NotifyAddInventory(NewItem);
	return true;
}

simulated function Timer()
{
	local PlayerController PC;
	local SPVolume_Pullup V;
	local SPVolume_PipeLine D;
	local SPVolume_WallVault P;
	local SPVolume_ZipLine LD;
	local SPVolume_DarkArea LV;

	PC = PlayerController(Controller);

	Super.Timer();

	if (bAdjustDodgeZ)
	{
		DodgeSpeedZ = DodgeZAmount;
	}

	if (PC != None)
	{
		foreach TouchingActors(class'SPVolume_Pipeline', D)
		{
			if (D != None)
			{
				PC.bCheatFlying = true;
			}
		}

		foreach TouchingActors(class'SPVolume_ZipLine', LD)
		{
			if (LD != None)
			{
				PC.bCheatFlying = false;
			}
		}

		foreach TouchingActors(class'SPVolume_Pullup', V)
		{
			if (V != None)
			{
				if (V.bDisplayMessage)
					PC.ReceiveLocalizedMessage(class'SPVolume_PullupMessage', 0, PlayerReplicationInfo);
			}
		}

		foreach TouchingActors(class'SPVolume_WallVault', P)
		{
			if (P != None)
			{
				if (P.bDisplayMessage)
					PC.ReceiveLocalizedMessage(class'SPVolume_WallVaultMessage', 0, PlayerReplicationInfo);
			}
		}

		if (bLightSystem)
		{
			foreach TouchingActors(class'SPVolume_DarkArea', LV)
			{
				if (LV != None)
				{
						Visibility = 0;
						if (PC != None)
							PC.ReceiveLocalizedMessage(class'LightMessage_Invisible',0,Controller.PlayerReplicationInfo);
				}
				return;
			}

			Visibility = 128;
		}
	}
}

function Tick(float Deltatime)
{
	local SPVolume_WallVault V;
	local PlayerController PC;

	PC = PlayerController(Controller);

	Super.Tick(Deltatime);


	foreach TouchingActors(class'SPVolume_WallVault', V)
	{
		if (V != None)
		{
		    	if (PC != None && PC.DoubleClickDir >= DCLICK_Active)
			{
		        	PC.ClearDoubleClick();
		        	PC.DoubleClickDir = DCLICK_None;
			}
		}
	}
}

function Died(Controller Killer, class<DamageType> damageType, vector HitLocation)
{
	Super.Died(Killer, DamageType, HitLocation);

	bRespawning = true; // Checked once the player has died at least once so his/her inventory can be restored in SPGame.
}

simulated function ClientSetMusic(string NewSong, byte NewSection, byte NewCdTrack, EMusicTransition NewTransition)
{
	Level.Song = NewSong;
	Level.PlayMusic(NewSong, 2);
}

defaultproperties
{
	RequiredEquipment(0)=""
	RequiredEquipment(1)=""
	InvItem=0
	AmbientGlow=0
	bDramaticLighting=false
}