Class SoldierMonster extends Monster;

var Weapon OverrideWeapon;
var() config string SoldierWeapon;
var() config bool bNoThrowWeapon;
var bool bSuperAggressive;

function TossWeapon(Vector TossVel)
{
	if (bNoThrowWeapon)
    		return;

  	Super.TossWeapon(TossVel);
}

function bool AddInventory(Inventory newItem)
{
	if (newItem.IsA('FakeMonsterWeapon'))
	{
		// Override RPG's insistence of giving every monster the FakeMonsterWeapon and forcing it active
		OverrideWeapon = Weapon;
		newItem.Destroy();
		return false;
	}
	else
		return Super.AddInventory(newItem);
}

function PostBeginPlay()
{
	Super.PostBeginPlay();

    	if (Weapon != None && Weapon.Name == 'FakeMonsterWeapon')
      		Weapon.Destroy();

	RequiredEquipment[0] = SoldierWeapon;
	RequiredEquipment[1] = SoldierWeapon;
	RequiredEquipment[2] = SoldierWeapon;
	RequiredEquipment[3] = SoldierWeapon;

	AddDefaultInventory();

	SetTimer(5, true);
}

function RangedAttack(Actor A)
{
	if ( bShotAnim )
		return;

	if ( (VSize(A.Location - Location) < MeleeRange))
	{
		if (Weapon != None)
			Weapon.BotFire(False);
	}	
	else
	{
		if ( bSuperAggressive && !Controller.bPreparingMove && Controller.InLatentExecution(Controller.LATENT_MOVETOWARD) )
			return;
		if ( Controller.InLatentExecution(501) ) // LATENT_MOVETO
			return;

		if (Weapon != None)
			Weapon.BotFire(False);
	}
	Controller.bPreparingMove = true;
	Acceleration = vect(0,0,0);
	//bShotAnim = true;
}

function Timer()
{
	Weapon = OverrideWeapon;

	if (Health <= 0)
	{
		Destroy();
	}
}

function Died(Controller Killer, class<DamageType> damageType, vector HitLocation)
{
	Super.Died(Killer, DamageType, HitLocation);

	// SetCollision(false, false, false);
}

function PlayVictory()
{

	Controller.bPreparingMove = true;
	Acceleration = vect(0,0,0);
	bShotAnim = true;
    PlaySound(sound'staflp4k',SLOT_Interact);	
	SetAnimAction('gesture_point');
	Controller.Destination = Location;
	Controller.GotoState('TacticalMove','WaitForAnim');
}

simulated function SpawnGiblet( class<Gib> GibClass, Vector Location, Rotator Rotation, float GibPerterbation )
{
	return;
}


simulated function ChunkUp( Rotator HitRotation, float ChunkPerterbation ) // gam
{
	if ( (Level.NetMode != NM_Client) && (Controller != None) )
	{
		if ( Controller.bIsPlayer )
			Controller.PawnDied(self);
		else
			Controller.Destroy();
	}
}

simulated function PlayDying(class<DamageType> DamageType, vector HitLoc)
{
	local float frame, rate;
    local name seq;
	local LavaDeath LD;
	local BodyEffect BE;

	AmbientSound = None;
    bCanTeleport = false; // sjs - fix karma going crazy when corpses land on teleporters
    bReplicateMovement = false;
    bTearOff = true;
    bPlayedDeath = true;

    if (CurrentCombo != None)
        CurrentCombo.Destroy();

	HitDamageType = DamageType; // these are replicated to other clients
    TakeHitLocation = HitLoc;

    if ( DamageType != None )
    {
		if ( DamageType.default.bSkeletize )
		{
			SetOverlayMaterial(DamageType.Default.DamageOverlayMaterial, 4.0, true);
			if (!bSkeletized)
			{
				if ( (Level.NetMode != NM_DedicatedServer) && (SkeletonMesh != None) )
				{
					if ( DamageType.default.bLeaveBodyEffect )
					{
						BE = spawn(class'BodyEffect',self);
						if ( BE != None )
						{
							BE.DamageType = DamageType;
							BE.HitLoc = HitLoc;
							bFrozenBody = true;
						}
					}
					GetAnimParams( 0, seq, frame, rate );
					LinkMesh(SkeletonMesh, true);
					Skins.Length = 0;
					PlayAnim(seq, 0, 0);
					SetAnimFrame(frame);
				}
				if (Physics == PHYS_Walking)
					Velocity = Vect(0,0,0);
				TearOffMomentum *= 0.25;
				bSkeletized = true;
				if ( (Level.NetMode != NM_DedicatedServer) && (DamageType == class'FellLava') )
				{
					LD = spawn(class'LavaDeath', , , Location + vect(0, 0, 10), Rotation );
					if ( LD != None )
						LD.SetBase(self);
					PlaySound( sound'WeaponSounds.BExplosion5', SLOT_None, 1.5*TransientSoundVolume );
				}
			}
		}
		else if ( DamageType.Default.DeathOverlayMaterial != None )
			SetOverlayMaterial(DamageType.Default.DeathOverlayMaterial, DamageType.default.DeathOverlayTime, true);
		else if ( (DamageType.Default.DamageOverlayMaterial != None) && (Level.DetailMode != DM_Low) && !Level.bDropDetail )
			SetOverlayMaterial(DamageType.Default.DamageOverlayMaterial, 2*DamageType.default.DamageOverlayTime, true);
	}

    // stop shooting
    AnimBlendParams(1, 0.0);
    FireState = FS_None;
	LifeSpan = RagdollLifeSpan;

    GotoState('Dying');
    if ( BE != None )
		return;

	PlayDyingAnimation(DamageType, HitLoc);
}

function PlayDyingSound()
{
	// Dont play dying sound if a skeleton. Tricky without vocal chords.
	if ( bSkeletized )
		return;

	if ( bGibbed )
	{
        PlaySound(GibGroupClass.static.GibSound(), SLOT_Pain,3.5*TransientSoundVolume,true,500);
		return;
	}

    if ( HeadVolume.bWaterVolume )
    {
        PlaySound(GetSound(EST_Drown), SLOT_Pain,6*TransientSoundVolume,true,500);
        return;
    }

	PlaySound(SoundGroupClass.static.GetDeathSound(), SLOT_Pain,6*TransientSoundVolume, true,500);
}

defaultproperties
{
	Health=100
	SoldierWeapon="xWeapons.RocketLauncher"
	SightRadius=100000
	HearingThreshold=100000
	bMuffledHearing=false
     ChallengeSound(0)=Sound'PlayerSounds.JumpSounds.MaleDodge'
     ChallengeSound(1)=Sound'PlayerSounds.JumpSounds.MaleJump2'
     ChallengeSound(2)=Sound'PlayerSounds.JumpSounds.MaleJump1'
     ChallengeSound(3)=Sound'PlayerSounds.JumpSounds.MaleDodge'
     HitSound(0)=Sound'PlayerSounds.BHitCries.BHitCry2'
     HitSound(1)=Sound'PlayerSounds.BHitCries.BHitCry3'
     HitSound(2)=Sound'PlayerSounds.BHitCries.BHitCry2'
     HitSound(3)=Sound'PlayerSounds.BHitCries.BHitCry3'
     RagdollLifeSpan=30.000000
     RagImpactSounds(0)=Sound'GeneralImpacts.Wet.Breakbone_01'
     RagImpactSounds(1)=Sound'GeneralImpacts.Wet.Breakbone_02'
     RagImpactSounds(2)=Sound'GeneralImpacts.Wet.Breakbone_03'
     RagImpactSounds(3)=Sound'GeneralImpacts.Wet.Breakbone_04'
     bCanSwim=True
     bCanStrafe=True
     MeleeRange=150.000000
     JumpZ=550.000000
     GroundSpeed=500
     MovementAnims(1)="RunF"
     MovementAnims(2)="RunF"
     MovementAnims(3)="RunF"
     TurnLeftAnim="TurnL"
     TurnRightAnim="TurnR"
     SwimAnims(0)="Swim_Tread"
     SwimAnims(1)="Swim_Tread"
     SwimAnims(2)="Swim_Tread"
     SwimAnims(3)="Swim_Tread"
     WalkAnims(1)="WalkF"
     WalkAnims(2)="WalkF"
     WalkAnims(3)="WalkF"
     AirAnims(0)="JumpF_Mid"
     AirAnims(1)="JumpF_Mid"
     AirAnims(2)="JumpF_Mid"
     AirAnims(3)="JumpF_Mid"
     TakeoffAnims(0)="JumpF_Takeoff"
     TakeoffAnims(1)="JumpF_Takeoff"
     TakeoffAnims(2)="JumpF_Takeoff"
     TakeoffAnims(3)="JumpF_Takeoff"
     LandAnims(0)="JumpF_Land"
     LandAnims(1)="JumpF_Land"
     LandAnims(2)="JumpF_Land"
     LandAnims(3)="JumpF_Land"
     TauntAnims(0)="gesture_point"
     TauntAnims(1)="gesture_beckon"
     TauntAnims(2)="gesture_halt"
     TauntAnims(3)="gesture_cheer"
     TauntAnims(4)="PThrust"
     TauntAnims(5)="AssSmack"
     TauntAnims(6)="ThroatCut"
     TauntAnims(7)="Specific_1"
     DoubleJumpAnims(0)="JumpF_TakeOff"
     DoubleJumpAnims(1)="JumpF_TakeOff"
     DoubleJumpAnims(2)="JumpF_TakeOff"
     DoubleJumpAnims(3)="JumpF_TakeOff"
     DodgeAnims(0)="JumpF_TakeOff"
     DodgeAnims(1)="JumpF_TakeOff"
     DodgeAnims(2)="JumpF_TakeOff"
     DodgeAnims(3)="JumpF_TakeOff"
     AirStillAnim="JumpF_TakeOff"
     TakeoffStillAnim="JumpF_TakeOff"
     Mesh=SkeletalMesh'Hellions.Hellion_Kane'
